@@ -59,7 +59,7 @@ use DNS::Unbound::X ();
 our ($VERSION);
 
 BEGIN {
-    $VERSION = '0.06';
+    $VERSION = '0.07';
     XSLoader::load();
 }
 
@@ -346,7 +346,11 @@ sub debugout {
 
     my $fd = ref($fd_or_fh) ? fileno($fd_or_fh) : $fd_or_fh;
 
-    _ub_ctx_debugout( $self->{'_ub'}, $fd );
+    my $mode = _get_fd_mode_for_fdopen($fd) or do {
+        die DNS::Unbound::X->create('BadDebugFD', $fd, $!);
+    };
+
+    _ub_ctx_debugout( $self->{'_ub'}, $fd, $mode );
 
     return $self;
 }
